/// IMPORTING THIRD PARTY PACKAGES
import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';
import 'package:provider/provider.dart';

/// IMPORTING LOCAL PACKAGES
import 'package:zwap_design_system/zwap_design_system.dart';

/// The edit profile state to handle change values inside this card form
class EditProfileState extends ChangeNotifier{

  /// The values mapping
  final Map<String, dynamic> values;

  EditProfileState({required this.values});

  Map<String, dynamic> getValues(BuildContext context){
    Map<String, dynamic> tmp = {};
    context.read<DynamicQuestionState>().bodyData.forEach((key, value) {
      tmp[key] = value;
    });
    ImagePickerState imageProvider = context.read<ImagePickerState>();
    tmp['profilePic'] = imageProvider.currentImage != null ? imageProvider.currentImage!.absolute : "";
    this.values.addAll(tmp);
    return this.values;
  }


}

/// The edit profile card
class EditProfile extends StatelessWidget{

  @override
  Widget build(BuildContext context) {
    return Consumer<EditProfileState>(
        builder: (builder, provider, child){
          return Padding(
            padding: EdgeInsets.only(bottom: 40),
            child: Column(
              children: [
                BlueHeader(
                  childrenStack: [
                    FractionalTranslation(
                      translation: const Offset(0.0, 0.5),
                      child: Consumer<ImagePickerState>(
                          builder: (builder, provider, child){
                            return PickImage();
                          }
                      ),
                    )
                  ],
                  headerHeight: 80,
                  stackAlignment: AlignmentDirectional.center,
                ),
                Padding(
                  padding: EdgeInsets.only(top: 80),
                  child: Consumer<DynamicQuestionState>(
                      builder: (builder, provider, child){
                        return DynamicQuestion();
                      }
                  ),
                ),
              ],
            ),
          );
        }
    );
  }
}