/// IMPORTING THIRD PARTY PACKAGES
import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';
import 'package:provider/provider.dart';

/// IMPORTING LOCAL PACKAGES
import 'package:zwap_design_system/zwap_design_system.dart';


class NetworkFilterState extends ChangeNotifier{

  dynamic value;

  NetworkFilterState({required this.value});

  void changeValue(dynamic value){
    this.value = value;
    notifyListeners();
  }

}

class NetworkCustomDropDownStateExtended extends CustomDropDownState{

  final NetworkFilterState provider;

  NetworkCustomDropDownStateExtended({required this.provider});

  void onChangeValue (String? value){
    super.onChangeValue(value);
    this.provider.changeValue(value!);
  }

}

/// Dynamic filter in base of the current filter type
class NetworkFilter extends StatelessWidget{

  /// The network filter type
  final NetworkFilterElement networkFilter;

  /// Current value selected for the current filter
  final String currentValue;

  NetworkFilter({Key? key,
    required this.networkFilter,
    required this.currentValue,
  }): super(key: key);

  @override
  Widget build(BuildContext context) {
    NetworkFilterState provider = context.read<NetworkFilterState>();
    TextEditingController controller = TextEditingController();
    controller.addListener(() {
      provider.changeValue(controller.text);
    });
    switch(this.networkFilter.filterType){
      case FilterType.inputText:
        return BaseInput(
          placeholderText: this.networkFilter.placeholder,
          inputType: InputType.inputText,
          controller: controller,
        );
      case FilterType.inputDropDown:
        return ChangeNotifierProvider<NetworkCustomDropDownStateExtended>(
          create: (_) => NetworkCustomDropDownStateExtended(provider: provider),
          builder: (builder, dropDownProvider){
            return CustomDropDown(values: this.networkFilter.filtersOptions,);
          }
        );
      case FilterType.buttonSide:
        List<Widget> children = [];
        this.networkFilter.filtersOptions.forEach((element) {
          children.add(
            BaseButton(
                buttonText: element,
                buttonTypeStyle: element == currentValue ? ButtonTypeStyle.pinkyButton : ButtonTypeStyle.greyButton,
                onPressedCallback: () => provider.changeValue(element)
            )
          );
        });
        return Row(
          children: children,
        );
    }
  }



}