/// IMPORTING THIRD PARTY PACKAGES
import 'package:flutter/cupertino.dart';
import 'package:taastrap/colStrap/colStrap.dart';
import 'package:provider/provider.dart';

/// IMPORTING LOCAL PACKAGES
import 'package:zwap_design_system/zwap_design_system.dart';

/// The state of this custom dropdown element
class DropDownTagState extends ChangeNotifier{

  /// The values state
  final List<String> values = [];

  /// Changing values
  void changeValues(String value, bool isAdd){
    if(isAdd){
      this.values.add(value);
    }
    else{
      int index = this.values.indexOf(value);
      this.values.removeAt(index);
    }
    notifyListeners();
  }

}

class CustomDropDownStateExtended extends CustomDropDownState{

  final DropDownTagState provider;

  CustomDropDownStateExtended({required this.provider});

  void onChangeValue (String? value){
    super.onChangeValue(value);
    this.provider.changeValues(value!, true);
  }

}

/// Custom widget to display dropdown with tag inside
class DropDownTag extends StatelessWidget{

  /// The values inside the dropdown list
  final List<String> values;

  DropDownTag({Key? key,
    required this.values,
  }): super(key: key);

  /// It retrieves the row with the custom tags inside in a responsive way
  Map<Widget, Map<String, int>> _getResponsiveChildren(DropDownTagState value){
    Map<Widget, Map<String, int>> finals = {};
    value.values.forEach((element) {
      Widget tmp = TagElement(
        tagText: element,
        icon: IconData(0),
        callBackClick: () => value.changeValues(element, false),
      );
      finals[tmp] = {'xl': 3, 'lg': 3, 'md': 4, 'sm': 6, 'xs': 6};
    });
    return finals;
  }

  @override
  Widget build(BuildContext context) {
    return Column(
      children: [
        Padding(
          padding: EdgeInsets.symmetric(vertical: 10),
          child: ChangeNotifierProvider<CustomDropDownStateExtended>(
            create: (_) => CustomDropDownStateExtended(provider: context.read<DropDownTagState>()),
            builder: (builder, child){
              return CustomDropDown(
                values: this.values,
              );
            }
          ),
        ),
        Padding(
          padding: EdgeInsets.symmetric(vertical: 10),
          child: Consumer<DropDownTagState>(
            builder: (builder, provider, child){
              return ResponsiveRow(
                children: this._getResponsiveChildren(provider),
              );
            }
          ),
        )
      ],
    );
  }



}